#
# spec file for package gpac
#
# Copyright (c) 2019 Packman Team <packman@links2linux.de>
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.links2linux.org/
#


%define sover   8
Name:           gpac
Version:        0.8.0
Release:        lp150.1.3
Summary:        A multimedia framework covering MPEG-4, VRML/X3D and SVG
License:        LGPL-2.1-or-later
Group:          Productivity/Multimedia/Video/Editors and Convertors
Url:            http://gpac.io
Source:         https://github.com/gpac/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source90:       %{name}-rpmlintrc
#PATCH-FIX-UPSTREAM i@marguerite.su - enable osmozilla and osmo4_wx
Patch1:         gpac-0.7.1-enable_V4Studio.patch
#PATCH-FIX-UPSTREAM i@marguerite.su - fix SVGGen ldflags
Patch2:         gpac-0.7.1-SVGGen_abuild.patch
#PATCH-FIX-UPSTREAM wengxuetian@gmail.com - fix E: 64bit-portability-issue
Patch3:         gpac-0.6.1-64bit-portability.patch
#PATCH-FIX-OPENSUSE marguerite@opensuse.org - libpng include dir fix
Patch4:         gpac-0.6.1-libpng-version-detection.patch
#PATCH-FIX-UPSTREAM marguerite@opensuse.org - use system amrnb/amrwb
Patch5:         gpac-0.7.1-system-amr.patch
#PATCH-FIX-UPSTREAM marguerite@opensuse.org - no gpac.pc in devel package
Patch6:         gpac-0.6.1-no-pc.patch
#PATCH-FIX-UPSTREAM marguerite@opensuse.org - fix gf_isom_set_pixel_aspect_ratio
# not available to the public
Patch9:         gpac-0.8.0-x264-export.patch
#PATCH-FIX-UPSTREAM marguerite@opensuse.org - fix u32 count redelaration
Patch10:        gpac-0.5.1-u32-count-redeclaration.patch
Patch11:        gpac.wx.patch
Patch12:        gpac.ssl.patch
BuildRequires:  ImageMagick
BuildRequires:  Mesa-devel
BuildRequires:  alsa-devel
BuildRequires:  dos2unix
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  freeglut-devel
BuildRequires:  freetype2-devel
BuildRequires:  gcc-c++
BuildRequires:  graphviz
BuildRequires:  liba52-devel
BuildRequires:  libfaad-devel
BuildRequires:  pkgconfig(libavcodec) = 57.107.100
BuildRequires:  pkgconfig(libavformat) = 57.83.100
BuildRequires:  pkgconfig(libswscale) = 4.8.100
BuildRequires:  pkgconfig(libavdevice) = 57.10.100
BuildRequires:  pkgconfig(libavutil) = 55.78.100
BuildRequires:  libjpeg-devel
BuildRequires:  libmad-devel
BuildRequires:  libogg-devel
BuildRequires:  libopenssl-devel
BuildRequires:  libpng-devel
BuildRequires:  libpulse-devel
BuildRequires:  librsvg-devel >= 2.5.0
BuildRequires:  libtheora-devel
BuildRequires:  libvorbis-devel
BuildRequires:  libxvidcore-devel
BuildRequires:  unzip
BuildRequires:  update-desktop-files
BuildRequires:  xz
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  libSDL-devel
BuildRequires:  pkgconfig(mozjs185)
BuildRequires:  pkgconfig(libopenjpeg)
%if 1
BuildRequires:  wxWidgets-wxcontainer-devel
%define _use_internal_dependency_generator 0
%define __find_requires %wx_requires
%else
BuildRequires:  wxWidgets-devel
%endif

%description
GPAC is a multimedia framework for MPEG-4, VRML/X3D and SVG/SMIL.

GPAC is built upon an implementation of the MPEG-4 Systems standard
(ISO/IEC 14496-1) developed from scratch in C.

The main development goal is to provide a clean (a.k.a. readable by
as many people as possible), small and flexible alternative to the
MPEG-4 Systems reference software (known as IM1 and distributed in
ISO/IEC 14496-5).

The second development goal is to achieve integration of recent
multimedia standards (SVG/SMIL, VRML, X3D, SWF, etc) into a single
framework. This stage is still under drafting but GPAC already
supports most of VRML97, some X3D as well as very simple SVG.

GPAC already features 2D and 3D multimedia playback, MPEG-4 Systems
encoders/multiplexers and publishing tools for content distribution.

GPAC is licensed under the GNU Lesser General Public License.

The current GPAC release (0.4.5) already covers a very large part of
the MPEG-4 standard, and features what can probably be seen as the
most advanced and robust 2D MPEG-4 Player available worldwide, as
well as a decent 3D MPEG-4/VRML player.

Author:         Jean Le Feuvre <jeanlf at users.sourceforge.net>

%package -n libgpac%{sover}
Summary:        Shared libraries for gpac
Group:          System/Libraries

%description -n libgpac%{sover}
Shared libraries for package gpac.

%package -n libgpac-devel
Summary:        Development files for gpac
Group:          Development/Languages/C and C++
Requires:       libgpac%{sover} = %{version}
# old name
Provides:       gpac-devel = %{version}
Obsoletes:      gpac-devel < %{version}

%description -n libgpac-devel
Development files for gpac.

Author:         Jean Le Feuvre <jeanlf@users.sourceforge.net>

%package -n Osmo4
Summary:        MPEG-4 Media player based on gpac
Group:          Productivity/Multimedia/Video/Players
Requires:       %{name} = %{version}

%description -n Osmo4
Osmo4 is an MPEG-4 player with the following features:
* MPEG-4 Systems player:
* Optimized 2D graphics renderer compliant with the Complete2D Scene
  Graph and Graphics profiles.
* Video and audio presentation achieved through plugins
* Multimedia player features:
* Timeline controls: play, pause, step.
* Graphics features: antialising, zoom and pan, scalable resizing
  of rendering area
* Support for Advanced Text and Graphics extension of MPEG-4 Systems
* Frame export to JPG, PNG, BMP.

Osmo4 enables the use of MPEG-4 Systems in a vast aplication domain,
among which:
* downloaded or streamed cartoons
* synchronized, interactive mixes of graphics, text, video and audio
* applications benefiting from MPEG-7 and MPEG-21 advances: meta-data,
  encryption, watermarking, rights management

%prep
%setup -q
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1

%build
# Fix encoding warnings
cp -p Changelog Changelog.origine
iconv -f ISO-8859-1 -t UTF8 Changelog.origine > Changelog
touch -r Changelog.origine Changelog
rm -rf Changelog.origine

cp -p doc/ipmpx_syntax.bt doc/ipmpx_syntax.bt.origine
iconv -f ISO-8859-1 -t UTF8 doc/ipmpx_syntax.bt.origine > doc/ipmpx_syntax.bt
touch -r doc/ipmpx_syntax.bt.origine doc/ipmpx_syntax.bt
rm -rf doc/ipmpx_syntax.bt.origine

sed -i~ '1 {s@^.*$@/*@}' src/utils/xml_parser.c

### corrects typo
sed -e 's|nb_droped|nb_dropped|g' -i applications/osmo4_wx/fileprops.cpp

# configure the beast
./configure \
    --prefix=%{_prefix} \
    --libdir="%{_lib}" \
    --mandir=%{_mandir} \
    --extra-cflags="%{optflags} -D_FILE_OFFSET_BITS=64 -D_LARGE_FILES -D_LARGEFILE_SOURCE=1 -DXP_UNIX -fPIC"

# make the beast (NO parallel build possible ...)
# fix I: File is compiled without RPM_OPT_FLAGS gpac doesn't respect any flags at all
cp config.h include/gpac/configuration.h
make %{?_smp_mflags} all CFLAG="%{optflags}"
make %{?_smp_mflags} sggen
make %{?_smp_mflags} -C applications/generators/SVG
make %{?_smp_mflags} -C applications/udptsseg

# create dev-docs
pushd doc
    doxygen -u
    doxygen
popd

%install
%make_install

# header files
make install-lib \
    DESTDIR=%{buildroot}

# generated sggen binaries
for i in MPEG4 SVG X3D; do
    install -m 755 applications/generators/$i/${i}Gen \
    	%{buildroot}%{_bindir}
done

# udptsseg
install -m 755 bin/gcc/udptsseg \
    %{buildroot}%{_bindir}

# Osmo4
install -m 755 bin/gcc/Osmo4 \
    %{buildroot}%{_bindir}

# icon
install -dm 755 %{buildroot}%{_datadir}/pixmaps
convert -size 48x48 applications/osmo4_wx/osmo4.xpm \
    Osmo4.png
install -m 644 Osmo4.png \
    %{buildroot}%{_datadir}/pixmaps

# menu-entry
install -dm 755 %{buildroot}%{_datadir}/applications
cat > Osmo4.desktop << EOF
[Desktop Entry]
Comment=MPEG-4 Media player based on gpac
Name=Osmo4
GenericName=MPEG-4 Media player based on gpac
Type=Application
Exec=Osmo4
Icon=Osmo4
Terminal=false
EOF
%suse_update_desktop_file -i Osmo4 AudioVideo Player

# static lib
rm -rf %{buildroot}%{_libdir}/*.a

# Windows includes
rm -rf %{buildroot}%{_includedir}/win32 %{buildroot}%{_includedir}/wince

%fdupes %{buildroot}

%post -n libgpac%{sover} -p /sbin/ldconfig

%postun -n libgpac%{sover} -p /sbin/ldconfig

%files
%doc AUTHORS BUGS Changelog README.md TODO
%doc doc/configuration.html
%license COPYING
%{_bindir}/DashCast
%{_bindir}/MP42TS
%{_bindir}/MP4Box
%{_bindir}/MP4Client
%{_bindir}/MPEG4Gen
%{_bindir}/X3DGen
%{_bindir}/SVGGen
%{_bindir}/udptsseg
%{_libdir}/%{name}/
%{_datadir}/%{name}/
%{_mandir}/man1/*

%files -n libgpac%{sover}
%{_libdir}/libgpac.so.%{sover}
%{_libdir}/libgpac.so.%{sover}.*

%files -n libgpac-devel
%doc doc/CODING_STYLE doc/ipmpx_syntax.bt
%{_includedir}/%{name}/
%{_libdir}/libgpac.so
%{_libdir}/pkgconfig/%{name}.pc

%files -n Osmo4
%{_bindir}/Osmo4
%{_datadir}/pixmaps/Osmo4.png
%{_datadir}/applications/Osmo4.desktop

%changelog
* Thu Jun 27 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.8.0
  General:
  * Many security fixes (static compile and fuzzing through AFL,
    always ongoing).
  * Many bugs fixes
  * Added :ncl option in log levels to disable color logs
  * More tests and coverage
  File Formats:
  * Better support of QTFF / ProRes files
  * Support for AV1
    + import and export
    + source formats: OBUs (Section 5), IVF and AnnexB
    + AV1 in HEIF
  * Support for color (nclc, nclx and ICC profiles) in HEIF and
    ISOBMFF
  * Support for HDR (mdcv, clli) info in HEIF and ISOBMFF
  * Support for alpha in HEIF
  * Support for enforcing pasp presence even for 1:1 ratios
  * HEVC temporal sublayer split in MP4Box
  * Allow meta storage before mdat for meta-only files (heif and
    co)
  * Added option to keep AU delimiter in isobmff samples
  * Support for opus import
  * Support for pixi and ccst in HEIF
  * DolbyVision 'dvcC' and partial 'dvhe' boxes for HDR
  * Support for VP9 import and playback
  * Sample dependency in avc and hevc importers, and track
    thinner for non-refs images
  * Support for audio_roll signaling
  * New audio import mode to control AudioSampleEntry creation
    (v0, v1 ISOBMFF, v1 QTFF)
  * xHE-AAC import with detection of sync samples
  * Added support for MPEG-H 3D audio boxes (no import yet)
  * Handle Vobsub empty SPU packets
  * Added auxv and pict support
  Common Encryption:
  * Fully compliant CENC supporting cenc, cens, cbc1 and cbcs
  * CENC for AV1
  * Improved DASH+CENC support, pssh in MPD
  * ForceClear mode for CENC to skip encryption without sample
    groups
  * Made senc in movie fragments always stored before truns
  * Added default values handling for cbcs and possibility to
    set protection system per track
  * Compatibility with OpenSSL 1.1.x
  Streaming and Adaptive Streaming:
  * Support for ATSC3.0 both US and Korean versions !
  * Support for for live splices (xlink period insertions) in
    DASH client
  * Automatic period continuity in DASH when no codec change
    between periods
  * Added DASH cue-base segmentation (XML based) and -dsap
    option to generate cue files from source
  * Support for BBA-0 and BOLA implementations
  * Write fragment defaults in trex even when not using them
  * Support for simple ssix for keyframe data byterange at the
    start of a segment
  * Moved segment template at AdaptationSet level if only one
    representation
  * Changed default bsmode in dasher if single input file
  * Added init-seg-ext option
  * Added -mvex-after-traks option to MP4Box when dashing for
    CMAF
  * Added segmentation option to insert a tfdt per traf
  * Added -closest mode for DASH segmentation
  * Added -bound option to use audio segmenting method for video
  * Renamed -dash-run-for to -run-for
  * Added '=' in dash templates
  * Improved bandwith estimation when using HTTP 1.1 chunk
    transfer
  * Add option to force moof base offsets
  MP4Box:
  * Added -catpl to concatenate from playlist in MP4Box
  * Added options to set movie timescale at import and dash time
  * Added mpd rip option and top-level box compressor in MP4Box
  * Made -dts skip timing check and added -dtsc for that
  * Made force-cat option more agressive
  * Support for MovieFragmentRandomAccess using -mfra option
  * Added -dtsx to dump timing without offset
  * Added -dnalc opt for nal CRC dump
  * Added chunk extraction up to time until end
  * ISOBMFF single track import now removes references by default
  Decoders:
  * Updated ffmpeg to 4.0.2
  * Moved to openHEVC 3.0 API
  * Added nvdec support (windows, linux) with reuse of decoder
    context for tiled VR
  * Added HEVC support to mediacodec on android
  * AV1 playback through ffmpeg
  * Opus playback through ffmpeg
  3D, VR and 360:
  * Added vrhud for multiviewpoint 360
  * Added forced visibility mode of tiles in VR
  * Added tile visibility debug mode
  * Added forced stereo output for openhevc
  * Disable face nav if mouse grabbed
  * Added simple face tracking vr navigation based on udp
    commands
  * Added PSVR support
  * Added mouse move emulation at window border to force sphere
    rotation when inactive
  * Changed tile visibility algo to sample points in mesh
  Players (Mobile and Desktop):
  * Added about extension
  * Added multiple audio objects in dynamic scene
  * Added addon splicing of main content
  * Added mosaic://v1:.:vN url support
  * Added gaze simulation through mouse and gaze-sphere
    visibility test
  Subtitles:
  * Allow * as argument of -srt|ttxt to dump all possible tracks
    (#925)
  * Improved support for WebVTT import
  * Improved support for WebVTT DASHing/fragmentation
  Misc:
  * OSX install now done through PKG and modify PATH env
    in/etc/paths
  * Added initial PMT version and disc marker to TS muxer
  * Moved dektec output to matrix API, added SDI clipping
  * Added temi periodic toggle and manual toggle in MP42TS
- Bumped soversion to 8
- Refreshed gpac-0.6.1-x264-export.patch as
  gpac-0.8.0-x264-export.patch
- Reworked gpac.ssl.patch (probably pointless, since it applies
  only to OpenSSL 1.0)
- Dropped gpac-0.7.1-install_DashCast.patch (merged upstream)
* Tue Oct  9 2018 aloisio@gmx.com
- Update to version 0.7.1
  * Minor bug fixes from 0.7.0
  version 0.7.0
  Overview of the community activity:
  * ~1550 commits since 0.6.0.
  * Launched a few side projects - cf https://github.com/gpac/.
  * New test public infrastructure.
  General
  * Many security fixes (static compile and fuzzing through AFL,
    always ongoing).
  * Colorized log.
  * Changed default audio volume to 100%% instead of 75%%.
  * Expose more experimental options through the documentation.
  * Improved GLES renderer on mobile platforms.
  * Improvements on AVI dump.
  * Fixed pkg-config Private.libs.
  * SAT>IP playback support.
  Codecs and File Formats
  * Added L-HEVC File Format support (SHVC/MV-HEVC tracks and
    HEVC Tile Tracks).
  * Added MPEG IFF (image File Format) support.
  * Range extension support for AVC and HEVC.
  * SHVC and MV-HEVC importers and playback: moved to final spec
    version (SHM6+).
  Adaptive streaming
  * Support of HLS with fragmented MP4 playback.
  * APIs: gf_mpd_() functions and new segmenter API.
  * Improved alternate groups.
  * More support for PIFF PSEC and Smooth Streaming ( file
    format & playback).
  * DASH client: pluggable algorithms + improvements with
    scalable contents.
  * The counter source from the DASH sequences added to the
    public content.
  * HLS and DASH playback minor fixes.
  * DASH client logs are clearer.
  VR and 360
  * Added support for DASH SRD in 360 for independent videos
    videos (NxM partial spheres) more
  * Added support for DASH SRD in 360 for HEVC tiled videos (NxM
    tiles on one sphere) - checkout tuto
  Mobile
  * Apple VideoToolBox hardware decoding support for OSX and iOS
    for AVC|H264.
  * Android hardware decoding hardware acceleration for AVC|H264
    (HEVC on its way).
  * YUV422 and YUV444 8 and 10 bit support in GLES renderer.
  * Android build is based on Android Studio.
  * Android: new File Manager.
  Subtitles
  * Import of TTML via NHML according to MPEG-4 part 30 improved.
- Refreshed gpac-0.6.1-enable_V4Studio.patch as
  gpac-0.7.1-enable_V4Studio.patch, gpac-0.5.0-SVGGen_abuild.patch
  as gpac-0.7.1-SVGGen_abuild.patch, gpac-0.5.0-system-amr.patch
  as gpac-0.7.1-system-amr.patch, gpac-0.6.1-no-pc.patch,
  gpac-0.6.1-x264-export.patch and gpac.wx.patch
- Added gpac-0.7.1-install_DashCast.patch
* Fri May  4 2018 olaf@aepfle.de
- Use ffmpeg3 versions of pkgconfig(libav*)
* Fri Feb 17 2017 olaf@aepfle.de
- fix some parts of wxWidgets-3_0 build failures
* Fri Apr 29 2016 aloisio@gmx.com
- Update to 0.6.1, see changelog
  https://github.com/gpac/gpac/releases/tag/v0.6.1
  https://github.com/gpac/gpac/releases/tag/v0.6.0
- Reworked patches:
  gpac-0.6.1-64bit-portability.patch
  gpac-0.6.1-enable_V4Studio.patch
  gpac-0.6.1-libpng-version-detection.patch
  gpac-0.6.1-no-pc.patch
  gpac-0.6.1-x264-export.patch
- Switched to ffmpeg 3.0
* Sat Sep 26 2015 olaf@aepfle.de
- Use pkgconfig(mozjs185), also on 11.4
* Tue Sep 22 2015 olaf@aepfle.de
- Use pkgconfig for some BuildRequires
* Sun Mar  1 2015 aloisio@gmx.com
- update to 0.5.2
  * fixes build problem with ffmpeg 2.5.x
* Sat Feb 28 2015 i@margueirte.su
- update 0.5.1.svn5619
- drop gpac-0.5.1-bufferoverflow.patch
  * upstream fixed
* Wed Nov  5 2014 i@margueirte.su
- update 0.5.1.svn5491
- disable browser plugin support
  * it depends on xulrunner, which is uncompatible during versions
    so we need to use many macros to fix it, hard to maintain
  * gpac is a fundamental package because it's used to build x264
    while fundamental package shouldn't have so complicated depe-
    ndencies
  * that brower plugin wasn't used by anyone
- add patch: gpac-0.5.1-u32-count-redeclaration.patch
  * it declared "u32 count" twice, change the first to countLang
- drop patch:
  * gpac-0.5.0-smjs_call_prop_stub.patch
  * gpac-0.5.0-js_getparent.patch
  * they were used to fix xulrunner, no longer needed
* Mon Jul 14 2014 olaf@aepfle.de
- fix compile of src/utils/xml_parser.c in sle11
* Fri May 30 2014 olaf@aepfle.de
- BuildRequire libopenjpeg only in 12.1 or later
* Sat Mar 22 2014 i@margueirte.su
- update 0.5.0.svn5178
- added patch: gpac-0.5.0-js_getparent.patch
  * fix "too many arguments for JS_GetParent" error after
    forcing USE_FFDEV_18
- added patch: gpac-0.5.0-bufferoverflow.patch
  * fix I: Statement is overflowing a buffer error in OBS.
* Fri Jul 26 2013 i@margueirte.su
- better detect libpng version
- fix no gpac.pc in -devel package
- export functions needed by x264
* Sun Jul 21 2013 i@margueirte.su
- update 0.5.0.svn4668
- revert "wo_application" changes, it fails the whole build
- remove patch: gpac-0.5.0-x264-export.patch, upstreamed
- add libpng15/libpng14 patches.
- use system libamrwb/libamrnb.
* Fri Feb  8 2013 obs@botter.cc
- svn4296 - includes fixes for compilation with Firefox 18
- disable while compiling with xulrunner 17.0.2
  * subpackage Osmo4
  * browser-client
  * MP4client in main package
* Mon Nov  5 2012 i@margueirte.su
- fix sles and < 1140 builds.
* Wed Oct 31 2012 i@margueirte.su
- fix Tumbleweed builds.
- adjust enable_V4Studio.patch.
  * do not use static lib for linking.
* Thu Oct  4 2012 i@marguerite.su
- update to 0.5.0
  * MPEG-DASH and HLS support (players and MP4Box)
  * MPEG-U Widgets and UPnP support in the player
  * Stereo and multiview display support
  * Better AVC and SVC support including OpenSVC decoder integration
  * More live tools: RTP, MPEG-TS, T-DMB support, scene encoders (BIFS and RME/DIMS)
  * iOS and Android support
  * and many other good things
- svn4192 fixes sf#3574796:
  * Osmozilla: change switch_up type from int to long, since xulrunner 15 doesn't support int type directly.
  * change bogus uuid in Osmozilla.
  * fix mozjs15 depreciated JS_ConstructObject to JS_New.
- enable_V4Studio patch
  * upstream masked Osmo4_wx and osmozilla. I enabled them and fix linker errors.
- smjs_call_prop_stub.patch
  * fix openSUSE xulrunner version.
- SVGGen_abuild.patch
  * fix applications/generators/SVG linker errors.
- 64bit-portability.patch
  * fix OBS errors and warnings.
- enable build udptsseg, a HTTP streaming tool.
- spec clean.
  * remove _with_amr. we're already in PMBS.
  * correct BuildRequires package names and remove unneeded Requires.
  * remove dos2unix fixes
  * remove 64bit adjustments. we use upstream options.
  * remove libpng-1.4.0 fix. no longer need.
  * remove SONAME. upstream did that.
  * remove openjpeg fix.
  * remove unneeded configure options.
  * remove < 1140 conditionals.
  * use new ffmpeg. upstream code change.
  * add IDL regeneration for newer xulrunner.
  * enable osmozilla for all openSUSE versions. although few need it.
- TODO: enable hbbtvplayer builds.
* Fri Dec 16 2011 pascal.bleser@opensuse.org
- fix build on recent openSUSE versions, failure was introduced by missing OPENJPEG_VERSION
* Mon Jan 11 2010 toni@links2linux.de
- fixed buildroot usage:
  Error: no modules found in /usr/src/packages/BUILDROOT/gpac-0.4.5-0.pm.5.17.x86_64/usr/lib64/gpac
* Tue Dec  2 2008 toni@links2linux.de
- update to 0.4.5
- added libgpac0 subpackage
- added librsvg2(-devel) to BuildRequires
- install also the *Gen applications
* Wed Sep 24 2008 toni@links2linux.de
- rebuild with new libffmpeg0-devel, libmad-devel, libfaad2-devel,
  libxvidcore-devel packages
- patched for new ffmpeg-API
  (bits_per_sample ==> bits_per_coded_sample, CODEC_ID_MP3LAME ==> CODEC_ID_MP3)
* Fri Dec 21 2007 toni@links2linux.de
- rebuild with new ffmpeg package
* Sun Jul  1 2007 toni@links2linux.de
- use --extra-flags, as CPFLAGS/OPTFLAGS are not recognized in configure
  thx to Richard Sotke <tee@teeforum.com>
* Fri Jun  1 2007 toni@links2linux.de
- merged in 64bit patch/spec-file and corrected BuildRequires
- added rebuild of idl
- should now build on all SuSE-10.x
* Thu May 31 2007 toni@links2linux.de
- update to 0.4.4
* Sat Apr 21 2007 toni@links2linux.de
- update to 0.4.3-cvs20070420
* Fri Mar  9 2007 toni@links2linux.de
- update to 0.4.3-cvs20070309
* Sun Jan 28 2007 toni@links2linux.de
- update to 0.4.3-cvs20070126
* Tue Jan 16 2007 toni@links2linux.de
- update to 0.4.3-cvs20070115
* Wed Dec 13 2006 toni@links2linux.de
- update to 0.4.3-cvs20061213
* Sat Dec  9 2006 toni@links2linux.de
- rebuild with browser-plugin and enabled --enable-amr
* Fri Dec  8 2006 toni@links2linux.de
- initial build 0.4.3-cvs20061114
